# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class WorksheetResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'worksheet_number': 'int',
        'worksheet_name': 'str',
        'url': 'str',
        'worksheet_contents': 'str'
    }

    attribute_map = {
        'worksheet_number': 'WorksheetNumber',
        'worksheet_name': 'WorksheetName',
        'url': 'URL',
        'worksheet_contents': 'WorksheetContents'
    }

    def __init__(self, worksheet_number=None, worksheet_name=None, url=None, worksheet_contents=None):  # noqa: E501
        """WorksheetResult - a model defined in Swagger"""  # noqa: E501

        self._worksheet_number = None
        self._worksheet_name = None
        self._url = None
        self._worksheet_contents = None
        self.discriminator = None

        if worksheet_number is not None:
            self.worksheet_number = worksheet_number
        if worksheet_name is not None:
            self.worksheet_name = worksheet_name
        if url is not None:
            self.url = url
        if worksheet_contents is not None:
            self.worksheet_contents = worksheet_contents

    @property
    def worksheet_number(self):
        """Gets the worksheet_number of this WorksheetResult.  # noqa: E501

        Worksheet number of the converted page, starting with 1 for the left-most worksheet  # noqa: E501

        :return: The worksheet_number of this WorksheetResult.  # noqa: E501
        :rtype: int
        """
        return self._worksheet_number

    @worksheet_number.setter
    def worksheet_number(self, worksheet_number):
        """Sets the worksheet_number of this WorksheetResult.

        Worksheet number of the converted page, starting with 1 for the left-most worksheet  # noqa: E501

        :param worksheet_number: The worksheet_number of this WorksheetResult.  # noqa: E501
        :type: int
        """

        self._worksheet_number = worksheet_number

    @property
    def worksheet_name(self):
        """Gets the worksheet_name of this WorksheetResult.  # noqa: E501

        The name of the worksheet  # noqa: E501

        :return: The worksheet_name of this WorksheetResult.  # noqa: E501
        :rtype: str
        """
        return self._worksheet_name

    @worksheet_name.setter
    def worksheet_name(self, worksheet_name):
        """Sets the worksheet_name of this WorksheetResult.

        The name of the worksheet  # noqa: E501

        :param worksheet_name: The worksheet_name of this WorksheetResult.  # noqa: E501
        :type: str
        """

        self._worksheet_name = worksheet_name

    @property
    def url(self):
        """Gets the url of this WorksheetResult.  # noqa: E501

        URL to the XLSX file of this worksheet; file is stored in an in-memory cache and will be deleted  # noqa: E501

        :return: The url of this WorksheetResult.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this WorksheetResult.

        URL to the XLSX file of this worksheet; file is stored in an in-memory cache and will be deleted  # noqa: E501

        :param url: The url of this WorksheetResult.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def worksheet_contents(self):
        """Gets the worksheet_contents of this WorksheetResult.  # noqa: E501

        Contents of the worksheet in bytes  # noqa: E501

        :return: The worksheet_contents of this WorksheetResult.  # noqa: E501
        :rtype: str
        """
        return self._worksheet_contents

    @worksheet_contents.setter
    def worksheet_contents(self, worksheet_contents):
        """Sets the worksheet_contents of this WorksheetResult.

        Contents of the worksheet in bytes  # noqa: E501

        :param worksheet_contents: The worksheet_contents of this WorksheetResult.  # noqa: E501
        :type: str
        """
        if worksheet_contents is not None and not re.search(r'^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$', worksheet_contents):  # noqa: E501
            raise ValueError(r"Invalid value for `worksheet_contents`, must be a follow pattern or equal to `/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/`")  # noqa: E501

        self._worksheet_contents = worksheet_contents

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WorksheetResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorksheetResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DocxTopLevelComment(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'path': 'str',
        'author': 'str',
        'author_initials': 'str',
        'comment_text': 'str',
        'comment_date': 'datetime',
        'reply_child_comments': 'list[DocxComment]',
        'done': 'bool'
    }

    attribute_map = {
        'path': 'Path',
        'author': 'Author',
        'author_initials': 'AuthorInitials',
        'comment_text': 'CommentText',
        'comment_date': 'CommentDate',
        'reply_child_comments': 'ReplyChildComments',
        'done': 'Done'
    }

    def __init__(self, path=None, author=None, author_initials=None, comment_text=None, comment_date=None, reply_child_comments=None, done=None):  # noqa: E501
        """DocxTopLevelComment - a model defined in Swagger"""  # noqa: E501

        self._path = None
        self._author = None
        self._author_initials = None
        self._comment_text = None
        self._comment_date = None
        self._reply_child_comments = None
        self._done = None
        self.discriminator = None

        if path is not None:
            self.path = path
        if author is not None:
            self.author = author
        if author_initials is not None:
            self.author_initials = author_initials
        if comment_text is not None:
            self.comment_text = comment_text
        if comment_date is not None:
            self.comment_date = comment_date
        if reply_child_comments is not None:
            self.reply_child_comments = reply_child_comments
        if done is not None:
            self.done = done

    @property
    def path(self):
        """Gets the path of this DocxTopLevelComment.  # noqa: E501

        Path to the comment in the document  # noqa: E501

        :return: The path of this DocxTopLevelComment.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this DocxTopLevelComment.

        Path to the comment in the document  # noqa: E501

        :param path: The path of this DocxTopLevelComment.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def author(self):
        """Gets the author of this DocxTopLevelComment.  # noqa: E501

        Author name of the comment  # noqa: E501

        :return: The author of this DocxTopLevelComment.  # noqa: E501
        :rtype: str
        """
        return self._author

    @author.setter
    def author(self, author):
        """Sets the author of this DocxTopLevelComment.

        Author name of the comment  # noqa: E501

        :param author: The author of this DocxTopLevelComment.  # noqa: E501
        :type: str
        """

        self._author = author

    @property
    def author_initials(self):
        """Gets the author_initials of this DocxTopLevelComment.  # noqa: E501

        Initials of the author of the comment  # noqa: E501

        :return: The author_initials of this DocxTopLevelComment.  # noqa: E501
        :rtype: str
        """
        return self._author_initials

    @author_initials.setter
    def author_initials(self, author_initials):
        """Sets the author_initials of this DocxTopLevelComment.

        Initials of the author of the comment  # noqa: E501

        :param author_initials: The author_initials of this DocxTopLevelComment.  # noqa: E501
        :type: str
        """

        self._author_initials = author_initials

    @property
    def comment_text(self):
        """Gets the comment_text of this DocxTopLevelComment.  # noqa: E501

        Text content of the comment  # noqa: E501

        :return: The comment_text of this DocxTopLevelComment.  # noqa: E501
        :rtype: str
        """
        return self._comment_text

    @comment_text.setter
    def comment_text(self, comment_text):
        """Sets the comment_text of this DocxTopLevelComment.

        Text content of the comment  # noqa: E501

        :param comment_text: The comment_text of this DocxTopLevelComment.  # noqa: E501
        :type: str
        """

        self._comment_text = comment_text

    @property
    def comment_date(self):
        """Gets the comment_date of this DocxTopLevelComment.  # noqa: E501

        Date timestamp of the comment  # noqa: E501

        :return: The comment_date of this DocxTopLevelComment.  # noqa: E501
        :rtype: datetime
        """
        return self._comment_date

    @comment_date.setter
    def comment_date(self, comment_date):
        """Sets the comment_date of this DocxTopLevelComment.

        Date timestamp of the comment  # noqa: E501

        :param comment_date: The comment_date of this DocxTopLevelComment.  # noqa: E501
        :type: datetime
        """

        self._comment_date = comment_date

    @property
    def reply_child_comments(self):
        """Gets the reply_child_comments of this DocxTopLevelComment.  # noqa: E501

        Child comments, that are replies to this one  # noqa: E501

        :return: The reply_child_comments of this DocxTopLevelComment.  # noqa: E501
        :rtype: list[DocxComment]
        """
        return self._reply_child_comments

    @reply_child_comments.setter
    def reply_child_comments(self, reply_child_comments):
        """Sets the reply_child_comments of this DocxTopLevelComment.

        Child comments, that are replies to this one  # noqa: E501

        :param reply_child_comments: The reply_child_comments of this DocxTopLevelComment.  # noqa: E501
        :type: list[DocxComment]
        """

        self._reply_child_comments = reply_child_comments

    @property
    def done(self):
        """Gets the done of this DocxTopLevelComment.  # noqa: E501

        True if this comment is marked as Done in Word, otherwise it is false  # noqa: E501

        :return: The done of this DocxTopLevelComment.  # noqa: E501
        :rtype: bool
        """
        return self._done

    @done.setter
    def done(self, done):
        """Sets the done of this DocxTopLevelComment.

        True if this comment is marked as Done in Word, otherwise it is false  # noqa: E501

        :param done: The done of this DocxTopLevelComment.  # noqa: E501
        :type: bool
        """

        self._done = done

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocxTopLevelComment, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocxTopLevelComment):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DocxSetFooterAddPageNumberRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'input_file_bytes': 'str',
        'input_file_url': 'str',
        'prepend_text': 'str'
    }

    attribute_map = {
        'input_file_bytes': 'InputFileBytes',
        'input_file_url': 'InputFileUrl',
        'prepend_text': 'PrependText'
    }

    def __init__(self, input_file_bytes=None, input_file_url=None, prepend_text=None):  # noqa: E501
        """DocxSetFooterAddPageNumberRequest - a model defined in Swagger"""  # noqa: E501

        self._input_file_bytes = None
        self._input_file_url = None
        self._prepend_text = None
        self.discriminator = None

        if input_file_bytes is not None:
            self.input_file_bytes = input_file_bytes
        if input_file_url is not None:
            self.input_file_url = input_file_url
        if prepend_text is not None:
            self.prepend_text = prepend_text

    @property
    def input_file_bytes(self):
        """Gets the input_file_bytes of this DocxSetFooterAddPageNumberRequest.  # noqa: E501

        Optional: Bytes of the input file to operate on  # noqa: E501

        :return: The input_file_bytes of this DocxSetFooterAddPageNumberRequest.  # noqa: E501
        :rtype: str
        """
        return self._input_file_bytes

    @input_file_bytes.setter
    def input_file_bytes(self, input_file_bytes):
        """Sets the input_file_bytes of this DocxSetFooterAddPageNumberRequest.

        Optional: Bytes of the input file to operate on  # noqa: E501

        :param input_file_bytes: The input_file_bytes of this DocxSetFooterAddPageNumberRequest.  # noqa: E501
        :type: str
        """
        if input_file_bytes is not None and not re.search(r'^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$', input_file_bytes):  # noqa: E501
            raise ValueError(r"Invalid value for `input_file_bytes`, must be a follow pattern or equal to `/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/`")  # noqa: E501

        self._input_file_bytes = input_file_bytes

    @property
    def input_file_url(self):
        """Gets the input_file_url of this DocxSetFooterAddPageNumberRequest.  # noqa: E501

        Optional: URL of a file to operate on as input.  This can be a public URL, or you can also use the begin-editing API to upload a document and pass in the secure URL result from that operation as the URL here (this URL is not public).  # noqa: E501

        :return: The input_file_url of this DocxSetFooterAddPageNumberRequest.  # noqa: E501
        :rtype: str
        """
        return self._input_file_url

    @input_file_url.setter
    def input_file_url(self, input_file_url):
        """Sets the input_file_url of this DocxSetFooterAddPageNumberRequest.

        Optional: URL of a file to operate on as input.  This can be a public URL, or you can also use the begin-editing API to upload a document and pass in the secure URL result from that operation as the URL here (this URL is not public).  # noqa: E501

        :param input_file_url: The input_file_url of this DocxSetFooterAddPageNumberRequest.  # noqa: E501
        :type: str
        """

        self._input_file_url = input_file_url

    @property
    def prepend_text(self):
        """Gets the prepend_text of this DocxSetFooterAddPageNumberRequest.  # noqa: E501

        Optional: extra text to add before the page number, for example if you want to show \"Page 1\" then you can set PrependText to \"Page\"  # noqa: E501

        :return: The prepend_text of this DocxSetFooterAddPageNumberRequest.  # noqa: E501
        :rtype: str
        """
        return self._prepend_text

    @prepend_text.setter
    def prepend_text(self, prepend_text):
        """Sets the prepend_text of this DocxSetFooterAddPageNumberRequest.

        Optional: extra text to add before the page number, for example if you want to show \"Page 1\" then you can set PrependText to \"Page\"  # noqa: E501

        :param prepend_text: The prepend_text of this DocxSetFooterAddPageNumberRequest.  # noqa: E501
        :type: str
        """

        self._prepend_text = prepend_text

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocxSetFooterAddPageNumberRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocxSetFooterAddPageNumberRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DocxCellStyle(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'path': 'str',
        'name': 'str',
        'format_id': 'int',
        'built_in_id': 'int'
    }

    attribute_map = {
        'path': 'Path',
        'name': 'Name',
        'format_id': 'FormatID',
        'built_in_id': 'BuiltInID'
    }

    def __init__(self, path=None, name=None, format_id=None, built_in_id=None):  # noqa: E501
        """DocxCellStyle - a model defined in Swagger"""  # noqa: E501

        self._path = None
        self._name = None
        self._format_id = None
        self._built_in_id = None
        self.discriminator = None

        if path is not None:
            self.path = path
        if name is not None:
            self.name = name
        if format_id is not None:
            self.format_id = format_id
        if built_in_id is not None:
            self.built_in_id = built_in_id

    @property
    def path(self):
        """Gets the path of this DocxCellStyle.  # noqa: E501

        The Path of the location of this object; leave blank for new rows  # noqa: E501

        :return: The path of this DocxCellStyle.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this DocxCellStyle.

        The Path of the location of this object; leave blank for new rows  # noqa: E501

        :param path: The path of this DocxCellStyle.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def name(self):
        """Gets the name of this DocxCellStyle.  # noqa: E501

        Name of the style  # noqa: E501

        :return: The name of this DocxCellStyle.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DocxCellStyle.

        Name of the style  # noqa: E501

        :param name: The name of this DocxCellStyle.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def format_id(self):
        """Gets the format_id of this DocxCellStyle.  # noqa: E501

        Format ID of the cell style  # noqa: E501

        :return: The format_id of this DocxCellStyle.  # noqa: E501
        :rtype: int
        """
        return self._format_id

    @format_id.setter
    def format_id(self, format_id):
        """Sets the format_id of this DocxCellStyle.

        Format ID of the cell style  # noqa: E501

        :param format_id: The format_id of this DocxCellStyle.  # noqa: E501
        :type: int
        """

        self._format_id = format_id

    @property
    def built_in_id(self):
        """Gets the built_in_id of this DocxCellStyle.  # noqa: E501

        Built=in ID of the cell style  # noqa: E501

        :return: The built_in_id of this DocxCellStyle.  # noqa: E501
        :rtype: int
        """
        return self._built_in_id

    @built_in_id.setter
    def built_in_id(self, built_in_id):
        """Sets the built_in_id of this DocxCellStyle.

        Built=in ID of the cell style  # noqa: E501

        :param built_in_id: The built_in_id of this DocxCellStyle.  # noqa: E501
        :type: int
        """

        self._built_in_id = built_in_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocxCellStyle, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocxCellStyle):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DocxStyle(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'style_id': 'str',
        'path': 'str',
        'bold': 'bool',
        'italic': 'bool',
        'underline': 'bool',
        'font_size': 'str',
        'font_family': 'str'
    }

    attribute_map = {
        'style_id': 'StyleID',
        'path': 'Path',
        'bold': 'Bold',
        'italic': 'Italic',
        'underline': 'Underline',
        'font_size': 'FontSize',
        'font_family': 'FontFamily'
    }

    def __init__(self, style_id=None, path=None, bold=None, italic=None, underline=None, font_size=None, font_family=None):  # noqa: E501
        """DocxStyle - a model defined in Swagger"""  # noqa: E501

        self._style_id = None
        self._path = None
        self._bold = None
        self._italic = None
        self._underline = None
        self._font_size = None
        self._font_family = None
        self.discriminator = None

        if style_id is not None:
            self.style_id = style_id
        if path is not None:
            self.path = path
        if bold is not None:
            self.bold = bold
        if italic is not None:
            self.italic = italic
        if underline is not None:
            self.underline = underline
        if font_size is not None:
            self.font_size = font_size
        if font_family is not None:
            self.font_family = font_family

    @property
    def style_id(self):
        """Gets the style_id of this DocxStyle.  # noqa: E501

        ID of the style  # noqa: E501

        :return: The style_id of this DocxStyle.  # noqa: E501
        :rtype: str
        """
        return self._style_id

    @style_id.setter
    def style_id(self, style_id):
        """Sets the style_id of this DocxStyle.

        ID of the style  # noqa: E501

        :param style_id: The style_id of this DocxStyle.  # noqa: E501
        :type: str
        """

        self._style_id = style_id

    @property
    def path(self):
        """Gets the path of this DocxStyle.  # noqa: E501

        The Path of the location of this object; leave blank for new tables  # noqa: E501

        :return: The path of this DocxStyle.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this DocxStyle.

        The Path of the location of this object; leave blank for new tables  # noqa: E501

        :param path: The path of this DocxStyle.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def bold(self):
        """Gets the bold of this DocxStyle.  # noqa: E501

        Style applies bold formatting  # noqa: E501

        :return: The bold of this DocxStyle.  # noqa: E501
        :rtype: bool
        """
        return self._bold

    @bold.setter
    def bold(self, bold):
        """Sets the bold of this DocxStyle.

        Style applies bold formatting  # noqa: E501

        :param bold: The bold of this DocxStyle.  # noqa: E501
        :type: bool
        """

        self._bold = bold

    @property
    def italic(self):
        """Gets the italic of this DocxStyle.  # noqa: E501

        Style applies italic formatting  # noqa: E501

        :return: The italic of this DocxStyle.  # noqa: E501
        :rtype: bool
        """
        return self._italic

    @italic.setter
    def italic(self, italic):
        """Sets the italic of this DocxStyle.

        Style applies italic formatting  # noqa: E501

        :param italic: The italic of this DocxStyle.  # noqa: E501
        :type: bool
        """

        self._italic = italic

    @property
    def underline(self):
        """Gets the underline of this DocxStyle.  # noqa: E501

        Style applies underline formatting  # noqa: E501

        :return: The underline of this DocxStyle.  # noqa: E501
        :rtype: bool
        """
        return self._underline

    @underline.setter
    def underline(self, underline):
        """Sets the underline of this DocxStyle.

        Style applies underline formatting  # noqa: E501

        :param underline: The underline of this DocxStyle.  # noqa: E501
        :type: bool
        """

        self._underline = underline

    @property
    def font_size(self):
        """Gets the font_size of this DocxStyle.  # noqa: E501

        Font size  # noqa: E501

        :return: The font_size of this DocxStyle.  # noqa: E501
        :rtype: str
        """
        return self._font_size

    @font_size.setter
    def font_size(self, font_size):
        """Sets the font_size of this DocxStyle.

        Font size  # noqa: E501

        :param font_size: The font_size of this DocxStyle.  # noqa: E501
        :type: str
        """

        self._font_size = font_size

    @property
    def font_family(self):
        """Gets the font_family of this DocxStyle.  # noqa: E501

        Font family  # noqa: E501

        :return: The font_family of this DocxStyle.  # noqa: E501
        :rtype: str
        """
        return self._font_family

    @font_family.setter
    def font_family(self, font_family):
        """Sets the font_family of this DocxStyle.

        Font family  # noqa: E501

        :param font_family: The font_family of this DocxStyle.  # noqa: E501
        :type: str
        """

        self._font_family = font_family

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocxStyle, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocxStyle):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cloudmersive_convert_api_client.api_client import ApiClient


class ConvertImageApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def convert_image_get_image_info(self, input_file, **kwargs):  # noqa: E501
        """Get information about an image  # noqa: E501

        Get details from an image such as size, format and MIME type, compression, EXIF data such as location, DPI, unique colors, transparency information, and more  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.convert_image_get_image_info(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :return: GetImageInfoResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.convert_image_get_image_info_with_http_info(input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.convert_image_get_image_info_with_http_info(input_file, **kwargs)  # noqa: E501
            return data

    def convert_image_get_image_info_with_http_info(self, input_file, **kwargs):  # noqa: E501
        """Get information about an image  # noqa: E501

        Get details from an image such as size, format and MIME type, compression, EXIF data such as location, DPI, unique colors, transparency information, and more  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.convert_image_get_image_info_with_http_info(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :return: GetImageInfoResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input_file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method convert_image_get_image_info" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `convert_image_get_image_info`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/image/get-info', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetImageInfoResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def convert_image_image_format_convert(self, format1, format2, input_file, **kwargs):  # noqa: E501
        """Image format conversion  # noqa: E501

        Convert between over 100 file formats, including key formats such as Photoshop (PSD), PNG, JPG, GIF, NEF, and BMP.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.convert_image_image_format_convert(format1, format2, input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str format1: Input file format as a 3+ letter file extension.  You can also provide UNKNOWN for unknown file formats. Supported formats include AAI, ART, ARW, AVS, BPG, BMP, BMP2, BMP3, BRF, CALS, CGM, CIN, CMYK, CMYKA, CR2, CRW, CUR, CUT, DCM, DCR, DCX, DDS, DIB, DJVU, DNG, DOT, DPX, EMF, EPDF, EPI, EPS, EPS2, EPS3, EPSF, EPSI, EPT, EXR, FAX, FIG, FITS, FPX, GIF, GPLT, GRAY, HDR, HEIC, HPGL, HRZ, ICO, ISOBRL, ISBRL6, JBIG, JNG, JP2, JPT, J2C, J2K, JPEG/JPG, JXR, MAT, MONO, MNG, M2V, MRW, MTV, NEF, ORF, OTB, P7, PALM, PAM, PBM, PCD, PCDS, PCL, PCX, PDF, PEF, PES, PFA, PFB, PFM, PGM, PICON, PICT, PIX, PNG, PNG8, PNG00, PNG24, PNG32, PNG48, PNG64, PNM, PPM, PSB, PSD, PTIF, PWB, RAD, RAF, RGB, RGBA, RGF, RLA, RLE, SCT, SFW, SGI, SID, SUN, SVG, TGA, TIFF, TIM, UIL, VIFF, VICAR, VBMP, WDP, WEBP, WPG, X, XBM, XCF, XPM, XWD, X3F, YCbCr, YCbCrA, YUV (required)
        :param str format2: Output (convert to this format) file format as a 3+ letter file extension.  Supported formats include AAI, ART, ARW, AVS, BPG, BMP, BMP2, BMP3, BRF, CALS, CGM, CIN, CMYK, CMYKA, CR2, CRW, CUR, CUT, DCM, DCR, DCX, DDS, DIB, DJVU, DNG, DOT, DPX, EMF, EPDF, EPI, EPS, EPS2, EPS3, EPSF, EPSI, EPT, EXR, FAX, FIG, FITS, FPX, GIF, GPLT, GRAY, HDR, HEIC, HPGL, HRZ, ICO, ISOBRL, ISBRL6, JBIG, JNG, JP2, JPT, J2C, J2K, JPEG/JPG, JXR, MAT, MONO, MNG, M2V, MRW, MTV, NEF, ORF, OTB, P7, PALM, PAM, PBM, PCD, PCDS, PCL, PCX, PDF, PEF, PES, PFA, PFB, PFM, PGM, PICON, PICT, PIX, PNG, PNG8, PNG00, PNG24, PNG32, PNG48, PNG64, PNM, PPM, PSB, PSD, PTIF, PWB, RAD, RAF, RGB, RGBA, RGF, RLA, RLE, SCT, SFW, SGI, SID, SUN, SVG, TGA, TIFF, TIM, UIL, VIFF, VICAR, VBMP, WDP, WEBP, WPG, X, XBM, XCF, XPM, XWD, X3F, YCbCr, YCbCrA, YUV (required)
        :param file input_file: Input file to perform the operation on. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.convert_image_image_format_convert_with_http_info(format1, format2, input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.convert_image_image_format_convert_with_http_info(format1, format2, input_file, **kwargs)  # noqa: E501
            return data

    def convert_image_image_format_convert_with_http_info(self, format1, format2, input_file, **kwargs):  # noqa: E501
        """Image format conversion  # noqa: E501

        Convert between over 100 file formats, including key formats such as Photoshop (PSD), PNG, JPG, GIF, NEF, and BMP.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.convert_image_image_format_convert_with_http_info(format1, format2, input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str format1: Input file format as a 3+ letter file extension.  You can also provide UNKNOWN for unknown file formats. Supported formats include AAI, ART, ARW, AVS, BPG, BMP, BMP2, BMP3, BRF, CALS, CGM, CIN, CMYK, CMYKA, CR2, CRW, CUR, CUT, DCM, DCR, DCX, DDS, DIB, DJVU, DNG, DOT, DPX, EMF, EPDF, EPI, EPS, EPS2, EPS3, EPSF, EPSI, EPT, EXR, FAX, FIG, FITS, FPX, GIF, GPLT, GRAY, HDR, HEIC, HPGL, HRZ, ICO, ISOBRL, ISBRL6, JBIG, JNG, JP2, JPT, J2C, J2K, JPEG/JPG, JXR, MAT, MONO, MNG, M2V, MRW, MTV, NEF, ORF, OTB, P7, PALM, PAM, PBM, PCD, PCDS, PCL, PCX, PDF, PEF, PES, PFA, PFB, PFM, PGM, PICON, PICT, PIX, PNG, PNG8, PNG00, PNG24, PNG32, PNG48, PNG64, PNM, PPM, PSB, PSD, PTIF, PWB, RAD, RAF, RGB, RGBA, RGF, RLA, RLE, SCT, SFW, SGI, SID, SUN, SVG, TGA, TIFF, TIM, UIL, VIFF, VICAR, VBMP, WDP, WEBP, WPG, X, XBM, XCF, XPM, XWD, X3F, YCbCr, YCbCrA, YUV (required)
        :param str format2: Output (convert to this format) file format as a 3+ letter file extension.  Supported formats include AAI, ART, ARW, AVS, BPG, BMP, BMP2, BMP3, BRF, CALS, CGM, CIN, CMYK, CMYKA, CR2, CRW, CUR, CUT, DCM, DCR, DCX, DDS, DIB, DJVU, DNG, DOT, DPX, EMF, EPDF, EPI, EPS, EPS2, EPS3, EPSF, EPSI, EPT, EXR, FAX, FIG, FITS, FPX, GIF, GPLT, GRAY, HDR, HEIC, HPGL, HRZ, ICO, ISOBRL, ISBRL6, JBIG, JNG, JP2, JPT, J2C, J2K, JPEG/JPG, JXR, MAT, MONO, MNG, M2V, MRW, MTV, NEF, ORF, OTB, P7, PALM, PAM, PBM, PCD, PCDS, PCL, PCX, PDF, PEF, PES, PFA, PFB, PFM, PGM, PICON, PICT, PIX, PNG, PNG8, PNG00, PNG24, PNG32, PNG48, PNG64, PNM, PPM, PSB, PSD, PTIF, PWB, RAD, RAF, RGB, RGBA, RGF, RLA, RLE, SCT, SFW, SGI, SID, SUN, SVG, TGA, TIFF, TIM, UIL, VIFF, VICAR, VBMP, WDP, WEBP, WPG, X, XBM, XCF, XPM, XWD, X3F, YCbCr, YCbCrA, YUV (required)
        :param file input_file: Input file to perform the operation on. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['format1', 'format2', 'input_file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method convert_image_image_format_convert" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'format1' is set
        if ('format1' not in params or
                params['format1'] is None):
            raise ValueError("Missing the required parameter `format1` when calling `convert_image_image_format_convert`")  # noqa: E501
        # verify the required parameter 'format2' is set
        if ('format2' not in params or
                params['format2'] is None):
            raise ValueError("Missing the required parameter `format2` when calling `convert_image_image_format_convert`")  # noqa: E501
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `convert_image_image_format_convert`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'format1' in params:
            path_params['format1'] = params['format1']  # noqa: E501
        if 'format2' in params:
            path_params['format2'] = params['format2']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/image/{format1}/to/{format2}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def convert_image_image_set_dpi(self, dpi, input_file, **kwargs):  # noqa: E501
        """Change image DPI  # noqa: E501

        Resize an image to have a different DPI  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.convert_image_image_set_dpi(dpi, input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int dpi: New DPI in pixels-per-inch, for example 300 DPI or 600 DPI (required)
        :param file input_file: Input file to perform the operation on. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.convert_image_image_set_dpi_with_http_info(dpi, input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.convert_image_image_set_dpi_with_http_info(dpi, input_file, **kwargs)  # noqa: E501
            return data

    def convert_image_image_set_dpi_with_http_info(self, dpi, input_file, **kwargs):  # noqa: E501
        """Change image DPI  # noqa: E501

        Resize an image to have a different DPI  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.convert_image_image_set_dpi_with_http_info(dpi, input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int dpi: New DPI in pixels-per-inch, for example 300 DPI or 600 DPI (required)
        :param file input_file: Input file to perform the operation on. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['dpi', 'input_file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method convert_image_image_set_dpi" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'dpi' is set
        if ('dpi' not in params or
                params['dpi'] is None):
            raise ValueError("Missing the required parameter `dpi` when calling `convert_image_image_set_dpi`")  # noqa: E501
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `convert_image_image_set_dpi`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'dpi' in params:
            path_params['dpi'] = params['dpi']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/image/set-dpi/{dpi}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def convert_image_multipage_image_format_convert(self, format1, format2, input_file, **kwargs):  # noqa: E501
        """Multi-page image format conversion  # noqa: E501

        Convert between over 100 file formats, including support for Multiple-Page formats (e.g. PDFs, TIFFs, etc. with multiple pages).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.convert_image_multipage_image_format_convert(format1, format2, input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str format1: Input file format as a 3+ letter file extension.  You can also provide UNKNOWN for unknown file formats.  Supported formats include AAI, ART, ARW, AVS, BPG, BMP, BMP2, BMP3, BRF, CALS, CGM, CIN, CMYK, CMYKA, CR2, CRW, CUR, CUT, DCM, DCR, DCX, DDS, DIB, DJVU, DNG, DOT, DPX, EMF, EPDF, EPI, EPS, EPS2, EPS3, EPSF, EPSI, EPT, EXR, FAX, FIG, FITS, FPX, GIF, GPLT, GRAY, HDR, HEIC, HPGL, HRZ, ICO, ISOBRL, ISBRL6, JBIG, JNG, JP2, JPT, J2C, J2K, JPEG/JPG, JXR, MAT, MONO, MNG, M2V, MRW, MTV, NEF, ORF, OTB, P7, PALM, PAM, PBM, PCD, PCDS, PCL, PCX, PDF, PEF, PES, PFA, PFB, PFM, PGM, PICON, PICT, PIX, PNG, PNG8, PNG00, PNG24, PNG32, PNG48, PNG64, PNM, PPM, PSB, PSD, PTIF, PWB, RAD, RAF, RGB, RGBA, RGF, RLA, RLE, SCT, SFW, SGI, SID, SUN, SVG, TGA, TIFF, TIM, UIL, VIFF, VICAR, VBMP, WDP, WEBP, WPG, X, XBM, XCF, XPM, XWD, X3F, YCbCr, YCbCrA, YUV (required)
        :param str format2: Output (convert to this format) file format as a 3+ letter file extension.  Supported formats include AAI, ART, ARW, AVS, BPG, BMP, BMP2, BMP3, BRF, CALS, CGM, CIN, CMYK, CMYKA, CR2, CRW, CUR, CUT, DCM, DCR, DCX, DDS, DIB, DJVU, DNG, DOT, DPX, EMF, EPDF, EPI, EPS, EPS2, EPS3, EPSF, EPSI, EPT, EXR, FAX, FIG, FITS, FPX, GIF, GPLT, GRAY, HDR, HEIC, HPGL, HRZ, ICO, ISOBRL, ISBRL6, JBIG, JNG, JP2, JPT, J2C, J2K, JPEG/JPG, JXR, MAT, MONO, MNG, M2V, MRW, MTV, NEF, ORF, OTB, P7, PALM, PAM, PBM, PCD, PCDS, PCL, PCX, PDF, PEF, PES, PFA, PFB, PFM, PGM, PICON, PICT, PIX, PNG, PNG8, PNG00, PNG24, PNG32, PNG48, PNG64, PNM, PPM, PSB, PSD, PTIF, PWB, RAD, RAF, RGB, RGBA, RGF, RLA, RLE, SCT, SFW, SGI, SID, SUN, SVG, TGA, TIFF, TIM, UIL, VIFF, VICAR, VBMP, WDP, WEBP, WPG, X, XBM, XCF, XPM, XWD, X3F, YCbCr, YCbCrA, YUV (required)
        :param file input_file: Input file to perform the operation on. (required)
        :return: MultipageImageFormatConversionResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.convert_image_multipage_image_format_convert_with_http_info(format1, format2, input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.convert_image_multipage_image_format_convert_with_http_info(format1, format2, input_file, **kwargs)  # noqa: E501
            return data

    def convert_image_multipage_image_format_convert_with_http_info(self, format1, format2, input_file, **kwargs):  # noqa: E501
        """Multi-page image format conversion  # noqa: E501

        Convert between over 100 file formats, including support for Multiple-Page formats (e.g. PDFs, TIFFs, etc. with multiple pages).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.convert_image_multipage_image_format_convert_with_http_info(format1, format2, input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str format1: Input file format as a 3+ letter file extension.  You can also provide UNKNOWN for unknown file formats.  Supported formats include AAI, ART, ARW, AVS, BPG, BMP, BMP2, BMP3, BRF, CALS, CGM, CIN, CMYK, CMYKA, CR2, CRW, CUR, CUT, DCM, DCR, DCX, DDS, DIB, DJVU, DNG, DOT, DPX, EMF, EPDF, EPI, EPS, EPS2, EPS3, EPSF, EPSI, EPT, EXR, FAX, FIG, FITS, FPX, GIF, GPLT, GRAY, HDR, HEIC, HPGL, HRZ, ICO, ISOBRL, ISBRL6, JBIG, JNG, JP2, JPT, J2C, J2K, JPEG/JPG, JXR, MAT, MONO, MNG, M2V, MRW, MTV, NEF, ORF, OTB, P7, PALM, PAM, PBM, PCD, PCDS, PCL, PCX, PDF, PEF, PES, PFA, PFB, PFM, PGM, PICON, PICT, PIX, PNG, PNG8, PNG00, PNG24, PNG32, PNG48, PNG64, PNM, PPM, PSB, PSD, PTIF, PWB, RAD, RAF, RGB, RGBA, RGF, RLA, RLE, SCT, SFW, SGI, SID, SUN, SVG, TGA, TIFF, TIM, UIL, VIFF, VICAR, VBMP, WDP, WEBP, WPG, X, XBM, XCF, XPM, XWD, X3F, YCbCr, YCbCrA, YUV (required)
        :param str format2: Output (convert to this format) file format as a 3+ letter file extension.  Supported formats include AAI, ART, ARW, AVS, BPG, BMP, BMP2, BMP3, BRF, CALS, CGM, CIN, CMYK, CMYKA, CR2, CRW, CUR, CUT, DCM, DCR, DCX, DDS, DIB, DJVU, DNG, DOT, DPX, EMF, EPDF, EPI, EPS, EPS2, EPS3, EPSF, EPSI, EPT, EXR, FAX, FIG, FITS, FPX, GIF, GPLT, GRAY, HDR, HEIC, HPGL, HRZ, ICO, ISOBRL, ISBRL6, JBIG, JNG, JP2, JPT, J2C, J2K, JPEG/JPG, JXR, MAT, MONO, MNG, M2V, MRW, MTV, NEF, ORF, OTB, P7, PALM, PAM, PBM, PCD, PCDS, PCL, PCX, PDF, PEF, PES, PFA, PFB, PFM, PGM, PICON, PICT, PIX, PNG, PNG8, PNG00, PNG24, PNG32, PNG48, PNG64, PNM, PPM, PSB, PSD, PTIF, PWB, RAD, RAF, RGB, RGBA, RGF, RLA, RLE, SCT, SFW, SGI, SID, SUN, SVG, TGA, TIFF, TIM, UIL, VIFF, VICAR, VBMP, WDP, WEBP, WPG, X, XBM, XCF, XPM, XWD, X3F, YCbCr, YCbCrA, YUV (required)
        :param file input_file: Input file to perform the operation on. (required)
        :return: MultipageImageFormatConversionResult
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['format1', 'format2', 'input_file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method convert_image_multipage_image_format_convert" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'format1' is set
        if ('format1' not in params or
                params['format1'] is None):
            raise ValueError("Missing the required parameter `format1` when calling `convert_image_multipage_image_format_convert`")  # noqa: E501
        # verify the required parameter 'format2' is set
        if ('format2' not in params or
                params['format2'] is None):
            raise ValueError("Missing the required parameter `format2` when calling `convert_image_multipage_image_format_convert`")  # noqa: E501
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `convert_image_multipage_image_format_convert`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'format1' in params:
            path_params['format1'] = params['format1']  # noqa: E501
        if 'format2' in params:
            path_params['format2'] = params['format2']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/image-multipage/{format1}/to/{format2}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MultipageImageFormatConversionResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ZipDirectory(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'directory_name': 'str',
        'directories_in_directory': 'list[ZipDirectory]',
        'files_in_directory': 'list[ZipFile]'
    }

    attribute_map = {
        'directory_name': 'DirectoryName',
        'directories_in_directory': 'DirectoriesInDirectory',
        'files_in_directory': 'FilesInDirectory'
    }

    def __init__(self, directory_name=None, directories_in_directory=None, files_in_directory=None):  # noqa: E501
        """ZipDirectory - a model defined in Swagger"""  # noqa: E501

        self._directory_name = None
        self._directories_in_directory = None
        self._files_in_directory = None
        self.discriminator = None

        if directory_name is not None:
            self.directory_name = directory_name
        if directories_in_directory is not None:
            self.directories_in_directory = directories_in_directory
        if files_in_directory is not None:
            self.files_in_directory = files_in_directory

    @property
    def directory_name(self):
        """Gets the directory_name of this ZipDirectory.  # noqa: E501

        Name of this directory  # noqa: E501

        :return: The directory_name of this ZipDirectory.  # noqa: E501
        :rtype: str
        """
        return self._directory_name

    @directory_name.setter
    def directory_name(self, directory_name):
        """Sets the directory_name of this ZipDirectory.

        Name of this directory  # noqa: E501

        :param directory_name: The directory_name of this ZipDirectory.  # noqa: E501
        :type: str
        """

        self._directory_name = directory_name

    @property
    def directories_in_directory(self):
        """Gets the directories_in_directory of this ZipDirectory.  # noqa: E501

        Child directories contained directly in this directory  # noqa: E501

        :return: The directories_in_directory of this ZipDirectory.  # noqa: E501
        :rtype: list[ZipDirectory]
        """
        return self._directories_in_directory

    @directories_in_directory.setter
    def directories_in_directory(self, directories_in_directory):
        """Sets the directories_in_directory of this ZipDirectory.

        Child directories contained directly in this directory  # noqa: E501

        :param directories_in_directory: The directories_in_directory of this ZipDirectory.  # noqa: E501
        :type: list[ZipDirectory]
        """

        self._directories_in_directory = directories_in_directory

    @property
    def files_in_directory(self):
        """Gets the files_in_directory of this ZipDirectory.  # noqa: E501

        Child files contained directly in this directory  # noqa: E501

        :return: The files_in_directory of this ZipDirectory.  # noqa: E501
        :rtype: list[ZipFile]
        """
        return self._files_in_directory

    @files_in_directory.setter
    def files_in_directory(self, files_in_directory):
        """Sets the files_in_directory of this ZipDirectory.

        Child files contained directly in this directory  # noqa: E501

        :param files_in_directory: The files_in_directory of this ZipDirectory.  # noqa: E501
        :type: list[ZipFile]
        """

        self._files_in_directory = files_in_directory

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ZipDirectory, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ZipDirectory):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class FindRegexMatch(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'character_offset_start': 'int',
        'character_offset_end': 'int',
        'containing_line': 'str',
        'match_value': 'str',
        'match_groups': 'list[str]'
    }

    attribute_map = {
        'character_offset_start': 'CharacterOffsetStart',
        'character_offset_end': 'CharacterOffsetEnd',
        'containing_line': 'ContainingLine',
        'match_value': 'MatchValue',
        'match_groups': 'MatchGroups'
    }

    def __init__(self, character_offset_start=None, character_offset_end=None, containing_line=None, match_value=None, match_groups=None):  # noqa: E501
        """FindRegexMatch - a model defined in Swagger"""  # noqa: E501

        self._character_offset_start = None
        self._character_offset_end = None
        self._containing_line = None
        self._match_value = None
        self._match_groups = None
        self.discriminator = None

        if character_offset_start is not None:
            self.character_offset_start = character_offset_start
        if character_offset_end is not None:
            self.character_offset_end = character_offset_end
        if containing_line is not None:
            self.containing_line = containing_line
        if match_value is not None:
            self.match_value = match_value
        if match_groups is not None:
            self.match_groups = match_groups

    @property
    def character_offset_start(self):
        """Gets the character_offset_start of this FindRegexMatch.  # noqa: E501

        0-based index of the start of the match  # noqa: E501

        :return: The character_offset_start of this FindRegexMatch.  # noqa: E501
        :rtype: int
        """
        return self._character_offset_start

    @character_offset_start.setter
    def character_offset_start(self, character_offset_start):
        """Sets the character_offset_start of this FindRegexMatch.

        0-based index of the start of the match  # noqa: E501

        :param character_offset_start: The character_offset_start of this FindRegexMatch.  # noqa: E501
        :type: int
        """

        self._character_offset_start = character_offset_start

    @property
    def character_offset_end(self):
        """Gets the character_offset_end of this FindRegexMatch.  # noqa: E501

        0-based index of the end of the match  # noqa: E501

        :return: The character_offset_end of this FindRegexMatch.  # noqa: E501
        :rtype: int
        """
        return self._character_offset_end

    @character_offset_end.setter
    def character_offset_end(self, character_offset_end):
        """Sets the character_offset_end of this FindRegexMatch.

        0-based index of the end of the match  # noqa: E501

        :param character_offset_end: The character_offset_end of this FindRegexMatch.  # noqa: E501
        :type: int
        """

        self._character_offset_end = character_offset_end

    @property
    def containing_line(self):
        """Gets the containing_line of this FindRegexMatch.  # noqa: E501

        Text content of the line containing the match  # noqa: E501

        :return: The containing_line of this FindRegexMatch.  # noqa: E501
        :rtype: str
        """
        return self._containing_line

    @containing_line.setter
    def containing_line(self, containing_line):
        """Sets the containing_line of this FindRegexMatch.

        Text content of the line containing the match  # noqa: E501

        :param containing_line: The containing_line of this FindRegexMatch.  # noqa: E501
        :type: str
        """

        self._containing_line = containing_line

    @property
    def match_value(self):
        """Gets the match_value of this FindRegexMatch.  # noqa: E501

        The match value  # noqa: E501

        :return: The match_value of this FindRegexMatch.  # noqa: E501
        :rtype: str
        """
        return self._match_value

    @match_value.setter
    def match_value(self, match_value):
        """Sets the match_value of this FindRegexMatch.

        The match value  # noqa: E501

        :param match_value: The match_value of this FindRegexMatch.  # noqa: E501
        :type: str
        """

        self._match_value = match_value

    @property
    def match_groups(self):
        """Gets the match_groups of this FindRegexMatch.  # noqa: E501

        Regular expression regex match groups; these correspond to the match values  # noqa: E501

        :return: The match_groups of this FindRegexMatch.  # noqa: E501
        :rtype: list[str]
        """
        return self._match_groups

    @match_groups.setter
    def match_groups(self, match_groups):
        """Sets the match_groups of this FindRegexMatch.

        Regular expression regex match groups; these correspond to the match values  # noqa: E501

        :param match_groups: The match_groups of this FindRegexMatch.  # noqa: E501
        :type: list[str]
        """

        self._match_groups = match_groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FindRegexMatch, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FindRegexMatch):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
